@@ -24,8 +24,6 @@
 # *  e-mail address 'scipion@cnb.csic.es'
 # *
 # **************************************************************************
-
-
 from os.path import abspath, basename
 
 from pwem.emlib.image import ImageHandler
@@ -130,17 +128,9 @@ class ProtImportTomograms(ProtTomoImportFiles, ProtTomoImportAcquisition):
         tomoSet.setSamplingRate(samplingRate)
 
         self._parseAcquisitionData()
+        fileNameList = []
         for fileName, fileId in self.iterFiles():
             x, y, z, n = imgh.getDimensions(fileName)
-            if fileName.endswith('.mrc') or fileName.endswith('.map'):
-                fileName += ':mrc'
-                if z == 1 and n != 1:
-                    zDim = n
-                    n = 1
-                else:
-                    zDim = z
-            else:
-                zDim = z
 
             origin = Transform()
 
@@ -149,17 +139,23 @@ class ProtImportTomograms(ProtTomoImportFiles, ProtTomoImportAcquisition):
             else:
                 origin.setShifts(x / -2. * samplingRate,
                                  y / -2. * samplingRate,
-                                 zDim / -2. * samplingRate)
+                                 z / -2. * samplingRate)
 
             tomo.setOrigin(origin)  # read origin from form
 
-            newFileName = _getUniqueFileName(self.getPattern(), fileName.split(':')[0])
+            newFileName = basename(fileName).split(':')[0]
+            if newFileName in fileNameList:
+                newFileName = _getUniqueFileName(self.getPattern(),
+                                                 fileName.split(':')[0])
+
+            fileNameList.append(newFileName)
+
             tsId = removeExt(newFileName)
             tomo.setTsId(tsId)
 
             if fileName.endswith(':mrc'):
                 fileName = fileName[:-4]
-            createAbsLink(fileName, abspath(self._getExtraPath(newFileName)))
+            createAbsLink(abspath(fileName), abspath(self._getExtraPath(newFileName)))
             tomo.setAcquisition(self._extractAcquisitionParameters(fileName))
 
             if n == 1:  # One volume per file
