@@ -23,6 +23,7 @@
 # *  e-mail address 'scipion@cnb.csic.es'
 # *
 # **************************************************************************
+from enum import Enum
 
 from pyworkflow.tests import DataSet
 
@@ -47,7 +48,9 @@ DataSet(name='tomo-em', folder='tomo-em',
                'noSamplingRateMdoc': 'NoPixelSpacing.mdoc',
                'noVoltagenoSRateMdoc': 'NoVoltage_NoPixelSpacing.mdoc',
                'someMissingAnglesMdoc': 'SomeTiltAnglesMissing_1_7_48.mdoc',
-               'noDoseMdoc': 'noDose.mdoc'
+               'noDoseMdoc': 'noDose.mdoc',
+               'ts1_imod': 'tutorialData/BBa.st',
+               'ts2_imod': 'tutorialData/BBb.st'
         })
 
 DataSet(name='reliontomo', folder='reliontomo',
@@ -55,3 +58,20 @@ DataSet(name='reliontomo', folder='reliontomo',
                'tomo1': '64K_defocus_m2_tomo_10_bin1_WBP_CatBinned1.mrc',
                'tomo2': '64K_defocus_m2_tomo_12_bin1_WBP_CatBinned1.mrc',
         })
+
+EMD_10439 = 'emd_10439'
+
+
+class DataSetEmd10439(Enum):
+    tomoEmd10439 = 'tomograms/emd_10439.mrc'
+    coords3dStarFile = 'importFromStarFiles/picking_001_parts.star'
+    coords3dStarFileWithSRate = 'importFromStarFiles/picking_001_parts_with_sRate.star'
+    subtomogramsStarFile = 'importFromStarFiles/class_ap_r_ali_k1_split.star'
+    scipionSqlite3dCoords = 'importFromScipionSqlite/coordinates.sqlite'
+    scipionSqlite3dCoordsSomeBad = 'importFromScipionSqlite/coordinates_3badCoords.sqlite'
+    tomoMaskAnnotated = 'tomomasksAnnotated/emd_10439_materials.mrc'
+    coords39Sqlite = 'coordinates/coordinates39.sqlite'
+
+
+DataSet(name=EMD_10439, folder=EMD_10439, files={el.name: el.value for el in DataSetEmd10439})
+
