@@ -33,6 +33,7 @@ import pwem.protocols as emprot
 from pyworkflow.tests import BaseTest, setupTestOutput, setupTestProject
 from pwem import Domain
 from pwem.objects import CTFModel, Transform
+from pyworkflow.utils import weakImport
 
 from . import DataSet
 from ..objects import SetOfTiltSeriesM, SetOfTiltSeries, Coordinate3D, Tomogram
@@ -107,7 +108,7 @@ class TestTomoBase(BaseTest):
         print("Writing new set to: %s" % fn2)
 
         def _updateCtf(j, ts, ti, tsOut, tiOut):
-            tiOut.setCTF(CTFModel(defocusU=j*1000, defocusAngle=j/2.0))
+            tiOut.setCTF(CTFModel(defocusU=j * 1000, defocusAngle=j / 2.0))
 
         testSet2 = SetOfTiltSeries(filename=fn2)
         testSet2.copyItems(testSet, updateTiCallback=_updateCtf)
@@ -286,6 +287,7 @@ class TestTomoSubSetsTomograms(BaseTest):
     """This class check if the protocol to import tomograms, create subsets,
      join subset and create a intersection of subsets of tomogram
      works properly."""
+
     @classmethod
     def setUpClass(cls):
         setupTestProject(cls)
@@ -420,6 +422,7 @@ class TestTomoSubSetsSubTomograms(BaseTest):
     """This class check if the protocol to import subtomograms, create subsets,
      join subset and create a intersection of subsets of tomogram
      works properly."""
+
     @classmethod
     def setUpClass(cls):
         setupTestProject(cls)
@@ -439,7 +442,7 @@ class TestTomoSubSetsSubTomograms(BaseTest):
 
         protImportCoordinates3d = self.newProtocol(
             tomo.protocols.ProtImportCoordinates3D,
-            auto=tomo.protocols.ProtImportCoordinates3D.IMPORT_FROM_EMAN,
+            auto=tomo.protocols.ProtImportCoordinates3D.IMPORT_FROM_FILES,
             filesPath=self.coords3D,
             importTomograms=protImportSubTomogram.outputTomograms,
             filesPattern='', boxSize=32,
@@ -581,6 +584,7 @@ class TestTomoPreprocessing(BaseTest):
             sphericalAberration=2.7,
             amplitudeContrast=0.1,
             samplingRate=0.675,
+            tiltAxisAngle=90,
             doseInitial=0,
             dosePerFrame=0.375)
         self.launchProtocol(protImport)
@@ -625,52 +629,52 @@ class TestTomoPreprocessing(BaseTest):
         self.launchProtocol(protCtffind)
 
 
-class TestTomoAssignAlignment(BaseTest):
-    """This class check if the protocol assign alignments for subtomograms/coordinates works properly."""
-
-    @classmethod
-    def setUpClass(cls):
-        setupTestProject(cls)
-        cls.dataset = DataSet.getDataSet('tomo-em')
-        cls.setOfSubtomograms = cls.dataset.getFile('basename.hdf')
-
-    def _runPreviousProtocols(self):
-        protImport = self.newProtocol(tomo.protocols.ProtImportSubTomograms,
-                                      filesPath=self.setOfSubtomograms,
-                                      samplingRate=5)
-        self.launchProtocol(protImport)
-        protImport2 = self.newProtocol(tomo.protocols.ProtImportSubTomograms,
-                                       filesPath=self.setOfSubtomograms,
-                                       samplingRate=5)
-        self.launchProtocol(protImport2)
-        from xmipp2.protocols import Xmipp2ProtMLTomo
-        protMltomo = self.newProtocol(Xmipp2ProtMLTomo,
-                                      inputVolumes=protImport.outputSubTomograms,
-                                      randomInitialization=True,
-                                      numberOfReferences=1,
-                                      numberOfIters=3,
-                                      angularSampling=30)
-        self.launchProtocol(protMltomo)
-        self.assertIsNotNone(protMltomo.outputSubtomograms,
-                             "There was a problem with the output")
-        self.assertIsNotNone(protMltomo.outputClassesSubtomo,
-                             "There was a problem with the output")
-        return protImport2, protMltomo
-
-    def _assignAlignment(self):
-        protImport2, protMltomo = self._runPreviousProtocols()
-        assign = self.newProtocol(tomo.protocols.ProtAlignmentAssignSubtomo,
-                                  input=protImport2.outputSubTomograms,
-                                  inputAlignment=protMltomo.outputSubtomograms)
-        self.launchProtocol(assign)
-        self.assertIsNotNone(assign.outputAligned,
-                             "There was a problem with the output")
-        return assign
-
-    def test_assignAlignment(self):
-        assign = self._assignAlignment()
-        self.assertTrue(assign.outputAligned.getFirstItem().hasTransform())
-        return assign
+# class TestTomoAssignAlignment(BaseTest):
+#     """This class check if the protocol assign alignments for subtomograms/coordinates works properly."""
+#
+#     @classmethod
+#     def setUpClass(cls):
+#         setupTestProject(cls)
+#         cls.dataset = DataSet.getDataSet('tomo-em')
+#         cls.setOfSubtomograms = cls.dataset.getFile('basename.hdf')
+#
+#     def _runPreviousProtocols(self):
+#         protImport = self.newProtocol(tomo.protocols.ProtImportSubTomograms,
+#                                       filesPath=self.setOfSubtomograms,
+#                                       samplingRate=5)
+#         self.launchProtocol(protImport)
+#         protImport2 = self.newProtocol(tomo.protocols.ProtImportSubTomograms,
+#                                        filesPath=self.setOfSubtomograms,
+#                                        samplingRate=5)
+#         self.launchProtocol(protImport2)
+#         from xmipp2.protocols import Xmipp2ProtMLTomo
+#         protMltomo = self.newProtocol(Xmipp2ProtMLTomo,
+#                                       inputVolumes=protImport.outputSubTomograms,
+#                                       randomInitialization=True,
+#                                       numberOfReferences=1,
+#                                       numberOfIters=3,
+#                                       angularSampling=30)
+#         self.launchProtocol(protMltomo)
+#         self.assertIsNotNone(protMltomo.outputSubtomograms,
+#                              "There was a problem with the output")
+#         self.assertIsNotNone(protMltomo.outputClassesSubtomo,
+#                              "There was a problem with the output")
+#         return protImport2, protMltomo
+#
+#     def _assignAlignment(self):
+#         protImport2, protMltomo = self._runPreviousProtocols()
+#         assign = self.newProtocol(tomo.protocols.ProtAlignmentAssignSubtomo,
+#                                   input=protImport2.outputSubTomograms,
+#                                   inputAlignment=protMltomo.outputSubtomograms)
+#         self.launchProtocol(assign)
+#         self.assertIsNotNone(assign.outputAligned,
+#                              "There was a problem with the output")
+#         return assign
+#
+#     def test_assignAlignment(self):
+#         assign = self._assignAlignment()
+#         self.assertTrue(assign.outputAligned.getFirstItem().hasTransform())
+#         return assign
 
 
 class TestTomoAssignTomo2Subtomo(BaseTest):
@@ -713,93 +717,98 @@ class TestTomoAssignTomo2Subtomo(BaseTest):
         # It can not be checked properly with current test data
         return tomo2subtomo
 
-class TestParticlesToSubtomograms(BaseTest):
-    """
-    This class create a set of subtomograms from a set of particles
-    """
 
-    @classmethod
-    def setUpClass(cls):
-        setupTestProject(cls)
-        cls.dataset = DataSet.getDataSet('tomo-em')
-        cls.setOfSubtomograms = cls.dataset.getFile('basename.hdf')
+with weakImport("xmipptomo"):
+    from xmipptomo.protocols.protocol_project_top import SubtomoProjectOutput
 
-    def _importSubtomoSet(self):
-        protImportSubtomo = self.newProtocol(tomo.protocols.ProtImportSubTomograms,
-                                             filesPath=self.setOfSubtomograms,
-                                             samplingRate=5)
-        self.launchProtocol(protImportSubtomo)
-        self.assertIsNotNone(protImportSubtomo.outputSubTomograms)
-        self.assertSetSize(protImportSubtomo.outputSubTomograms, 4,
-                           "The output size must be 4")
-        return protImportSubtomo
 
-    def _splitSet(self, inputSet, numberOfSets):
-        protSplitSet = self.newProtocol(emprot.ProtSplitSet,
-                                        inputSet=inputSet,
-                                        numberOfSets=numberOfSets,
-                                        randomize=True)
-        self.launchProtocol(protSplitSet)
-        return protSplitSet
+    class TestParticlesToSubtomograms(BaseTest):
+        """
+        This class create a set of subtomograms from a set of particles
+        """
 
-    def test_particlesToSubTomograms(self):
-        try:
-            from xmipptomo.protocols.protocol_project_top import XmippProtSubtomoProject
-            from xmipp3.protocols.protocol_cl2d import XmippProtCL2D
-        except ImportError:
-            print('To run this test, scipion-em-xmipptomo and scipion-em-xmipp2'
-                  ' are required. This test will not be executed unless these '
-                  'plugins are installed')
-            return
-        subtomograms = self._importSubtomoSet()
-        protSubtraction = self.newProtocol(XmippProtSubtomoProject,
-                                           input=subtomograms.outputSubTomograms)
-        self.launchProtocol(protSubtraction)
-        self.assertSetSize(protSubtraction.outputParticles, 4,
-                           "The number of projections generated must be 4")
+        @classmethod
+        def setUpClass(cls):
+            setupTestProject(cls)
+            cls.dataset = DataSet.getDataSet('tomo-em')
+            cls.setOfSubtomograms = cls.dataset.getFile('basename.hdf')
 
-        splitSet = self._splitSet(protSubtraction.outputParticles, 2)
-        protParticlesToSubtomograms = self.newProtocol(tomo.protocols.Prot2DParticlesToSubtomograms,
-                                      inputSubtomogramSet=subtomograms.outputSubTomograms,
-                                      inputSet=splitSet.outputParticles01)
-        self.launchProtocol(protParticlesToSubtomograms)
-        self.assertIsNotNone(protParticlesToSubtomograms.outputSubtomograms)
-        self.assertSetSize(protParticlesToSubtomograms.outputSubtomograms, 2,
-                           "The number of subtomograms must be 2")
+        def _importSubtomoSet(self):
+            protImportSubtomo = self.newProtocol(tomo.protocols.ProtImportSubTomograms,
+                                                 filesPath=self.setOfSubtomograms,
+                                                 samplingRate=5)
+            self.launchProtocol(protImportSubtomo)
+            self.assertIsNotNone(protImportSubtomo.outputSubTomograms)
+            self.assertSetSize(protImportSubtomo.outputSubTomograms, 4,
+                               "The output size must be 4")
+            return protImportSubtomo
 
-        protParticlesToSubtomograms = self.newProtocol(tomo.protocols.Prot2DParticlesToSubtomograms,
-                                                       inputSubtomogramSet=subtomograms.outputSubTomograms,
-                                                       inputSet=splitSet.outputParticles02)
-        self.launchProtocol(protParticlesToSubtomograms)
-        self.assertIsNotNone(protParticlesToSubtomograms.outputSubtomograms)
-        self.assertSetSize(protParticlesToSubtomograms.outputSubtomograms, 2,
-                           "The number of subtomograms must be 2")
+        def _splitSet(self, inputSet, numberOfSets):
+            protSplitSet = self.newProtocol(emprot.ProtSplitSet,
+                                            inputSet=inputSet,
+                                            numberOfSets=numberOfSets,
+                                            randomize=True)
+            self.launchProtocol(protSplitSet)
+            return protSplitSet
 
-        protClassification2D = self.newProtocol(XmippProtCL2D,
-                                                inputParticles=protSubtraction.outputParticles,
-                                                numberOfClasses=2,
-                                                numberOfInitialClasses=2)
-        self.launchProtocol(protClassification2D)
-        self.assertSetSize(protClassification2D.outputClasses, 2,
-                           "The number of classes must be 2")
+        def test_particlesToSubTomograms(self):
+            try:
+                from xmipptomo.protocols.protocol_project_top import XmippProtSubtomoProject
+                from xmipp3.protocols.protocol_cl2d import XmippProtCL2D
+            except ImportError:
+                print('To run this test scipion-em-xmipptomo is required. '
+                      'This test will not be executed unless this '
+                      'plugin is installed.')
+                return
+            subtomograms = self._importSubtomoSet()
+            projector = self.newProtocol(XmippProtSubtomoProject,
+                                         input=subtomograms.outputSubTomograms)
+            self.launchProtocol(projector)
+            output = getattr(projector, SubtomoProjectOutput.particles.name)
+            self.assertSetSize(output, 4, "The number of projections generated must be 4")
 
-        splitSet = self._splitSet(protClassification2D.outputClasses, 2)
-        protParticlesToSubtomograms = self.newProtocol(tomo.protocols.Prot2DParticlesToSubtomograms,
-                                                       inputSubtomogramSet=subtomograms.outputSubTomograms,
-                                                       inputSet=splitSet.outputClasses2D01)
+            splitSet = self._splitSet(output, 2)
+            protParticlesToSubtomograms = self.newProtocol(tomo.protocols.Prot2DParticlesToSubtomograms,
+                                                           inputSubtomogramSet=subtomograms.outputSubTomograms,
+                                                           inputSet=splitSet.outputParticles01)
+            self.launchProtocol(protParticlesToSubtomograms)
+            self.assertIsNotNone(protParticlesToSubtomograms.outputSubtomograms)
+            self.assertSetSize(protParticlesToSubtomograms.outputSubtomograms, 2,
+                               "The number of subtomograms must be 2")
 
-        self.launchProtocol(protParticlesToSubtomograms)
-        self.assertIsNotNone(protParticlesToSubtomograms.outputSubtomograms)
+            protParticlesToSubtomograms = self.newProtocol(tomo.protocols.Prot2DParticlesToSubtomograms,
+                                                           inputSubtomogramSet=subtomograms.outputSubTomograms,
+                                                           inputSet=splitSet.outputParticles02)
+            self.launchProtocol(protParticlesToSubtomograms)
+            self.assertIsNotNone(protParticlesToSubtomograms.outputSubtomograms)
+            self.assertSetSize(protParticlesToSubtomograms.outputSubtomograms, 2,
+                               "The number of subtomograms must be 2")
 
-        protParticlesToSubtomograms1 = self.newProtocol(tomo.protocols.Prot2DParticlesToSubtomograms,
-                                                       inputSubtomogramSet=subtomograms.outputSubTomograms,
-                                                       inputSet=splitSet.outputClasses2D02)
-        self.launchProtocol(protParticlesToSubtomograms1)
-        self.assertIsNotNone(protParticlesToSubtomograms1.outputSubtomograms)
+            protClassification2D = self.newProtocol(XmippProtCL2D,
+                                                    inputParticles=output,
+                                                    numberOfClasses=2,
+                                                    numberOfInitialClasses=2)
+            self.launchProtocol(protClassification2D)
+            self.assertSetSize(protClassification2D.outputClasses, 2,
+                               "The number of classes must be 2")
 
-        self.assertEqual((protParticlesToSubtomograms.outputSubtomograms.getSize() +
-                         protParticlesToSubtomograms1.outputSubtomograms.getSize()), 4,
-                         "The total number of subtomograms must be 4")
+            splitSet = self._splitSet(protClassification2D.outputClasses, 2)
+            protParticlesToSubtomograms = self.newProtocol(tomo.protocols.Prot2DParticlesToSubtomograms,
+                                                           inputSubtomogramSet=subtomograms.outputSubTomograms,
+                                                           inputSet=splitSet.outputClasses2D01)
+
+            self.launchProtocol(protParticlesToSubtomograms)
+            self.assertIsNotNone(protParticlesToSubtomograms.outputSubtomograms)
+
+            protParticlesToSubtomograms1 = self.newProtocol(tomo.protocols.Prot2DParticlesToSubtomograms,
+                                                            inputSubtomogramSet=subtomograms.outputSubTomograms,
+                                                            inputSet=splitSet.outputClasses2D02)
+            self.launchProtocol(protParticlesToSubtomograms1)
+            self.assertIsNotNone(protParticlesToSubtomograms1.outputSubtomograms)
+
+            self.assertEqual((protParticlesToSubtomograms.outputSubtomograms.getSize() +
+                              protParticlesToSubtomograms1.outputSubtomograms.getSize()), 4,
+                             "The total number of subtomograms must be 4")
 
 
 class TestTomoSplitEvenOdd(BaseTest):
@@ -943,6 +952,16 @@ class TestTomoCoordinatesOrigin(BaseTest):
         self.assertEqual(-0.5 * z, trPosition[2],
                          'SCIPION: Conversion did not return the expected value for Z axis')
 
-
-if __name__ == 'main':
-    pass
+    def test_Scipion_Origin_noTomo(self):
+        """Test coordinate position where there is no tomogram associated.
+        """
+        self._createCoordinate3D()
+        self.coord._volumePointer.set(None)
+        x, y, z = self.Tomo.getDim()
+        trPosition = self.coord.getPosition(const.SCIPION)
+        self.assertEqual(-0.5 * x, trPosition[0],
+                         'SCIPION: Conversion did not return the expected value for X axis without a tomo')
+        self.assertEqual(-0.5 * y, trPosition[1],
+                         'SCIPION: Conversion did not return the expected value for Y axis without a tomo')
+        self.assertEqual(-0.5 * z, trPosition[2],
+                         'SCIPION: Conversion did not return the expected value for Z axis without a tomo')
